@@ -247,7 +247,7 @@ def create_tfrecord_unlabeled(out_filename, addrs, ids, IMAGE_SIZE = (192,192)):
 		""")
 
 
-__init__ == "__main__":
+if __name__ == "__main__":
 	pass
 else:
 	import os
